@@ -26,7 +26,7 @@ File.open(arg0, "w") {|file|
 	text.lines{|line|
 		if last_line
 			long = last_line.chop + line
-			if not (/pack_((start)|(end))/.match(long))
+			#if not (/pack_((start)|(end))/.match(long))
 				if m = /^\s*proc #{prefix}([a-z]+_)?([a-z]+_)?([a-z]+_)?([a-z]+_)?\w*\*\(\s*(\w+): (\w+)/.match(long)
 					a, b, c, d, pp, dt = m[1..6]
 					if a && pp && dt
@@ -49,7 +49,7 @@ File.open(arg0, "w") {|file|
 						end
 					end
 				end
-			end
+			#end
 			file.write(last_line)
 		end
 		last_line = line.dup
