@@ -1,5 +1,5 @@
 #!/bin/bash
-# S. Salewski, 14-MAY-2014
+# S. Salewski, 26-MAY-2014
 # Generate GTK3 bindings for Nimrod -- this is for GDK headers 3.12.1
 # we try to process all headers, including win32, wayland, quartz, broadway
 # currently I can test only with x11
@@ -907,6 +907,15 @@ sed -i "s/ QuartzScreen/ TQuartzScreen/g" final.nim
 sed -i "s/ QuartzVisual/ TQuartzVisual/g" final.nim
 sed -i "s/ QuartzWindow/ TQuartzWindow/g" final.nim
 
+#sed -i "s/proc get_setting\*(/wxyz get_setting\*(/g" final.nim
+#sed -i "s/proc get_modifier_mask\*(/wxyz get_modifier_mask\*(/g" final.nim
+perl -0777 -p -i -e "s/(\nproc set_)(\w\w*)(\*\(.*?})/\1\2\3\nproc \`\2=\`\3/sg" final.nim
+perl -0777 -p -i -e "s/(\nproc get_)(\w\w*)(\*\(.*?})/\1\2\3\nproc \2\3/sg" final.nim
+#sed -i "s/wxyz get_setting\*(/proc get_setting\*(/g" final.nim
+#sed -i "s/wxyz get_modifier_mask\*(/proc get_modifier_mask\*(/g" final.nim
+
+ruby ../fix_enum_prefix.rb final.nim
+
 mv final.nim gdk3.nim
 
 #nimrod c gdk3.nim
